<?php
/**
 * Sets up the theme and provides some helper functions. Some helper functions
 * are used in the theme as custom template tags. Others are attached to action and
 * filter hooks in WordPress to change core functionality.
 * For more information on hooks, actions, and filters, see https://codex.wordpress.org/ 
 */


/*********************************************************************************************************
* Basic
**********************************************************************************************************/


	function seos_blue_scripts() {
		wp_enqueue_script( 'jq', get_template_directory_uri() . '/js/jq.js', array(), '1.0.0', true );
		wp_enqueue_script( 'top', get_template_directory_uri() . '/js/top.js', array(), '1.0.0', true );
		if (is_singular() && comments_open()) {wp_enqueue_script('comment-reply');}
	}

	add_action( 'wp_enqueue_scripts', 'seos_blue_scripts' );


	function seos_blue_add_editor_styles() {
			add_editor_style( get_template_directory_uri() . '/style.css' );
		}

		if ( ! isset( $content_width ) ) $content_width = 600;
	
	function seosblue_setup() {
		add_action( 'admin_init', 'seos_blue_add_editor_styles' );
		add_theme_support('title-tag');
		add_theme_support('automatic-feed-links');
		add_theme_support('post-thumbnails');
	}

	add_action( 'after_setup_theme', 'seosblue_setup' );

/*********************************************************************************************************
* Register Sidebar
**********************************************************************************************************/


	function seosblue_widgets_init() {
		register_sidebar( array(
			'id'          => ('right'),
			'name'        => __( 'right', 'seosblue'),
			'description' => __( 'This sidebar is right.', 'seosblue' ),
		) );

		register_sidebar( array(
			'id'          => ('left'),
			'name'        => __( 'left', 'seosblue' ),
			 'description' => __( 'This sidebar is left.', 'seosblue' ),
		) );

}

		add_action( 'widgets_init', 'seosblue_widgets_init' );



/*********************************************************************************************************
* Register Nav Menu
**********************************************************************************************************/


		register_nav_menus(array(
			'menu-top' => __('Menu top', 'seosblue')
		));



/*********************************************************************************************************
* Search Form
**********************************************************************************************************/


		function my_search_form( $form ) {
			$form = '<form method="get" id="searchform" class="searchform" action="' . home_url( '/' ) . '" >
			<input type="text" value="' . get_search_query() . '" name="s" id="s" />
			<input type="submit" id="searchsubmit" value="'. esc_attr__( '','seosblue' ) .'" />
			</form>';
			return $form;
		}

		add_filter( 'get_search_form', 'my_search_form' );


/*********************************************************************************************************
* Pagination. 
**********************************************************************************************************/


		if ( ! function_exists( 'mb_pagination' ) ) :

		function mb_pagination() {
			global $wp_query;
			$current = max( 1, get_query_var('paged') );
			$big = 242425757; // need an unlikely integer

			$pagination_return = paginate_links( array(
				'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
				'format' => '?paged=%#%',
				'current' => $current,
				'total' => $wp_query->max_num_pages,
				'next_text' => '&raquo;',
				'prev_text' => '&laquo;'
			) );

			if ( ! empty( $pagination_return ) ) {
				echo '<div class="pagination">';
				echo '<div class="total-pages">';
				echo '</div>';
				echo $pagination_return;
				echo '</div>';
			}
		}
		endif; 

 	$seosblue_page = array(
		'before'           => '<p>' . __( 'Pages:', 'seosblue' ),
		'after'            => '</p>',
		'link_before'      => '',
		'link_after'       => '',
		'next_or_number'   => 'number',
		'separator'        => ' ',
		'nextpagelink'     => __( 'Next page', 'seosblue' ),
		'previouspagelink' => __( 'Previous page', 'seosblue' ),
		'pagelink'         => '%',
		'echo'             => 1
	);
 
        wp_link_pages( $seosblue_page);



/*********************************************************************************************************
* Load CSS
**********************************************************************************************************/


		function seosblue_css() {		   
				wp_enqueue_style('seosblue_style', get_stylesheet_uri());
			}

		add_action('wp_enqueue_scripts', 'seosblue_css');



/*********************************************************************************************************
* Custom header
**********************************************************************************************************/



		$seosblue_custom_header_logo  = array(
			'width'        => 1300,
			'height'        => 100,
			'random-default' => true,
			'flex-height'            => true,
			'flex-width'             => false,
			'header-text'            => false,
		);

		add_theme_support( 'custom-header', $seosblue_custom_header_logo );



/*********************************************************************************************************
* Custom Colors Customize
**********************************************************************************************************/


		function seosblue_colors($wp_customize) {


/********************************************
* Hover color
*********************************************/
    

		$wp_customize->add_setting('seosblue_hover_color', array(        
  	      'default' => 'CE0000',
		    'sanitize_callback' => 'sanitize_hex_color'
  	  ));  
	
		$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'seosblue_hover_color', array(
		'label' => __('Hover Color', 'seosblue'),       
  	      'section' => 'colors',
  	      'settings' => 'seosblue_hover_color'
  	  )));


 /********************************************
* Header Color
*********************************************/ 
 

		$wp_customize->add_setting('seosblue_header_color', array(         
		'default'     => 'FFFFFF',
		 'sanitize_callback' => 'sanitize_hex_color'
		)); 	

		$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'seosblue_header_color', array(
		'label' => __('Header Color', 'seosblue'),        
		 'section' => 'colors',
		'settings' => 'seosblue_header_color'
		)));


 /********************************************
* Nav Hover Color
*********************************************/ 
 

		$wp_customize->add_setting('seosblue_nav_hover_color', array(         
		'default'     => '2e93db',
		'sanitize_callback' => 'sanitize_hex_color'
		)); 	

		$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'seosblue_nav_hover_color', array(
		'label' => __('Nav Hover Color', 'seosblue'),        
		'section' => 'colors',
		'settings' => 'seosblue_nav_hover_color'
		)));
			
 /********************************************
* Footer Background
*********************************************/ 
	

		$wp_customize->add_setting('seosblue_footer_background_color', array(         
		'default'     => '2e93db',
		'sanitize_callback' => 'sanitize_hex_color'
		)); 	

		$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'seosblue_footer_background_color', array(
		'label' => __('Footer Background Color', 'seosblue'),        
		'section' => 'colors',
		'settings' => 'seosblue_footer_background_color'
		)));
		
}
		add_action('customize_register', 'seosblue_colors');	
?><?php
		function seosblue_customize_css() {
    ?>
		<style type="text/css">
		header, header p, header h1 {color:<?php echo get_theme_mod('seosblue_header_color'); ?>;}   
		a:hover, details a:hover {color:<?php echo get_theme_mod('seosblue_hover_color'); ?>;}
		nav ul li a:hover, nav ul ul li a:hover {color:<?php echo get_theme_mod('seosblue_nav_hover_color'); ?>;}     
 		footer {background:<?php echo get_theme_mod('seosblue_footer_background_color'); ?>;}
 		.option-con {border:<?php echo get_theme_mod('seosblue_footer_background_color'); ?>;}    
		</style>
    <?php
	

	
}
		add_action('wp_head', 'seosblue_customize_css');



/*********************************************************************************************************
* Custom Background Color
**********************************************************************************************************/


		$custom_background = array(
			'default-color'          => 'FFFFFF',
			'wp-head-callback'       => '_custom_background_cb',
		);
		add_theme_support( 'custom-background', $custom_background );
		
		

/*********************************************************************************************************
* Excerpt
**********************************************************************************************************/


		function new_excerpt_more( $more ) {
			return ' <a class="read-more" href="'. get_permalink( get_the_ID() ) . '">' . __('Read More', 'seosblue') . '</a>';
		}
			add_filter( 'excerpt_more', 'new_excerpt_more' );

		function custom_excerpt_length( $length ) {
			return 50;
		}
		add_filter( 'excerpt_length', 'custom_excerpt_length', 999 );

/*********************************************************************************
 * Seos Blue - how to use
**********************************************************************************/


if ( ! function_exists( 'seos_blue_how_to_use' ) ) :
	function seos_blue_how_to_use( $wp_customize ) {
 
		$wp_customize->add_section( 'seos_blue_how_to_use_section' , array(
			'title'       => __( 'How to use Seos Blue', 'seosblue' ),
			'description' => __( '<a class="button button-primary" href="http://seosthemes.com/seos-blue/">How to use Seos Blue</a>', 'seosblue' ),
			'priority'   => 1,
		) );
		
		$wp_customize->add_setting( 'seos_blue_how_to_use', array (
			'sanitize_callback' => 'esc_url',
		) );
		
		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'seos_blue_how_to_use', array(
			'label'    => __( 'How to use Seos Blue', 'seosblue' ),
			'section'  => 'seos_blue_how_to_use_section',
			'settings' => 'seos_blue_how_to_use',
			'type'     => 'radio',

		) ) );
		
}
endif;
		add_action('customize_register', 'seos_blue_how_to_use');